@@ -10,11 +10,11 @@ CGI::Info - Information about the CGI environment
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 SYNOPSIS
 
@@ -345,7 +345,7 @@ sub _sanitise_input {
 
 	$arg =~ s/<!--(.|\n)*-->//g;
 	# Allow :
-	$arg =~ s/[;<>\*|`&\$!?#\(\)\[\]\{\}'"\\]//g;
+	$arg =~ s/[;<>\*|`&\$!?#\(\)\[\]\{\}'"\\\r]//g;
 
 	return $arg;
 }
